package cn.estsh.i3plus.ext.mes.pcn.pojo.context;

import cn.estsh.i3plus.ext.mes.pcn.pojo.util.MesPcnExtConstWords;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import org.springframework.util.StringUtils;

import java.io.Serializable;

/**
 * 生产过程上下文对象-装配件清单信息
 */
@Data
public class MesProductionAssemblyContext implements Serializable {

    private static final long serialVersionUID = 2382117884422723639L;

    @ApiParam("生产工单号")
    private String workOrderNo;

    @ApiParam("装配件零件编码")
    private String assemblyPartNo;

    @ApiParam("装配件零件名称")
    private String assemblyPartName;

    @ApiParam("装配件条码")
    protected String assemblySn;

    @ApiParam("生产工单零件号")
    private String partNo;

    @ApiParam("生产工单零件名称")
    private String partName;

    @ApiParam("装配零件状态")
    protected Integer assemblyStatus;

    @ApiParam("是否跳过")
    protected Integer isSkip = CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue();

    @ApiParam("装配件条码确认方式")
    protected Integer matchType;

    @ApiParam("扫描规则")
    private String matchRule;

    @ApiParam("不可用规则")
    protected String prodRuleIgnoreCfg;

    @ApiParam("自制件ID")
    protected Long productSnId;

    @ApiParam("数据来源")
    protected Integer dataSource;

    @ApiParam("来源ID")
    protected Long sourceId;

    @ApiParam(value = "排序/非排序产品加工规则ID")
    private Long pid;

    @ApiParam("最小值")
    private Double minValue;

    @ApiParam("最大值")
    private Double maxValue;

    @ApiParam(value = "装备序号")
    protected Integer routeSeq;

    @ApiParam(value = "装配爆炸图FID")
    protected Long imageFileId;

    @ApiParam(value = "音频文件")
    protected Long audioFileId;

    @ApiParam(value = "装配爆炸图URL")
    protected String imageFileUrl;

    @ApiParam(value = "音频文件URL")
    protected String audioFileUrl;

    @ApiParam(value = "装配爆炸图URL")
    protected Integer fileIsFinished = CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue();

    @ApiParam("前道工艺代码")
    private String preCraftCode;

    @ApiParam("组织代码")
    private String organizeCode;

    @ApiParam("区域代码")
    private String areaCode;

    @ApiParam("生产线代码")
    private String workCenterCode;

    @ApiParam("工位代码")
    private String workCellCode;

    @ApiParam("设备代码")
    private String equipmentCode;

    @ApiParam("工序代码")
    private String processCode;

    @ApiParam("工序名称")
    private String processName;

    @ApiParam("工艺代码")
    private String craftCode;

    @ApiParam("工艺名称")
    private String craftName;

    @ApiParam(name = "数据关联键")
    protected Integer foreignKey;

    @ApiParam(value = "是否可复用条码")
    private Integer isRepeat = CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue();

    @ApiParam(value = "是否可复用条码是否写入上下文进行复用")
    protected Integer isRepeat2Cache = CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue();

    @ApiParam("匹配时间")
    protected String matchDatetime;

    public String repeatKeyToString() {
        if (StringUtils.isEmpty(this.equipmentCode) || StringUtils.isEmpty(this.matchType) || (StringUtils.isEmpty(this.matchRule) && StringUtils.isEmpty(this.assemblyPartNo))) return null;
        return String.format("%s:%s&%s:%s&%s:%s&%s:%s",
                MesPcnExtConstWords.EQUIPMENT_CODE, this.equipmentCode,
                MesPcnExtConstWords.MATCH_TYPE, this.matchType,
                MesPcnExtConstWords.MATCH_RULE, StringUtils.isEmpty(this.matchRule) ? MesPcnExtConstWords.EMPTY : this.matchRule,
                MesPcnExtConstWords.ASSEMBLY_PART_NO, StringUtils.isEmpty(this.assemblyPartNo) ? MesPcnExtConstWords.EMPTY : this.assemblyPartNo);
    }

}
